==> haskell-wai-handler-launch-3.0.2.4-170-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-wai-handler-launch.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-handler-launch
version: 3.0.2.4
id: wai-handler-launch-3.0.2.4-1cghc8hATIFAeEMF7nW7J4
key: wai-handler-launch-3.0.2.4-1cghc8hATIFAeEMF7nW7J4
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
synopsis: Launch a web app in the default browser.
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-handler-launch>.
category: Web
abi: 1937569cff4eea9ec293007580193af1
exposed: True
exposed-modules:
    Network.Wai.Handler.Launch
import-dirs: /usr/lib/ghc-8.6.5/site-local/wai-handler-launch-3.0.2.4
library-dirs: /usr/lib/ghc-8.6.5/site-local/wai-handler-launch-3.0.2.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/wai-handler-launch-3.0.2.4
hs-libraries: HSwai-handler-launch-3.0.2.4-1cghc8hATIFAeEMF7nW7J4
depends:
    async-2.2.1-GYH0rb5jjEHH7NChV9fWYh base-4.12.0.0
    bytestring-0.10.8.2 http-types-0.12.3-LIupN3s0vqzJPmAPHPcGbD
    process-1.6.5.0 streaming-commons-0.2.1.0-HmrzuoDyRxaA7jtrPjSoAN
    transformers-0.5.6.2 wai-3.2.2-FKI9I9MeRyhBwlVDOn737X
    warp-3.2.27-3ic6bRab1wbFInQKSaPpOa
haddock-interfaces: /usr/share/doc/haskell-wai-handler-launch/html/wai-handler-launch.haddock
haddock-html: /usr/share/doc/haskell-wai-handler-launch/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-handler-launch-3.0.2.4-171-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-wai-handler-launch.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-handler-launch
version: 3.0.2.4
id: wai-handler-launch-3.0.2.4-9UaN52xG8QD29AM9e9fUW6
key: wai-handler-launch-3.0.2.4-9UaN52xG8QD29AM9e9fUW6
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
synopsis: Launch a web app in the default browser.
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-handler-launch>.
category: Web
abi: 636c9c5b75982ba3d823ecbba7a5d285
exposed: True
exposed-modules:
    Network.Wai.Handler.Launch
import-dirs: /usr/lib/ghc-8.6.5/site-local/wai-handler-launch-3.0.2.4
library-dirs: /usr/lib/ghc-8.6.5/site-local/wai-handler-launch-3.0.2.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/wai-handler-launch-3.0.2.4
hs-libraries: HSwai-handler-launch-3.0.2.4-9UaN52xG8QD29AM9e9fUW6
depends:
    async-2.2.1-GYH0rb5jjEHH7NChV9fWYh base-4.12.0.0
    bytestring-0.10.8.2 http-types-0.12.3-LIupN3s0vqzJPmAPHPcGbD
    process-1.6.5.0 streaming-commons-0.2.1.1-H5KixW5IiofdqNPa2NHpD
    transformers-0.5.6.2 wai-3.2.2-FKI9I9MeRyhBwlVDOn737X
    warp-3.2.27-EZcQrhbgPBiGRLcQ5Hoes6
haddock-interfaces: /usr/share/doc/haskell-wai-handler-launch/html/wai-handler-launch.haddock
haddock-html: /usr/share/doc/haskell-wai-handler-launch/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
